@@ -6,26 +6,52 @@ from datetime import (
     datetime as Datetime,
     time as Time,
     timedelta as Timedelta,
-    timezone as Timezone)
+    timezone as Timezone,
+)
 from decimal import Decimal
 from enum import Enum
 from ipaddress import IPv4Address, IPv4Network
 from json import dumps
 from uuid import UUID
 
-import pg8000
-from pg8000.converters import (
-    BIGINT, BIGINT_ARRAY, BOOLEAN, CIDR_ARRAY, DATE, FLOAT_ARRAY, INET,
-    INTEGER_ARRAY, JSON, JSONB, JSONB_ARRAY, JSON_ARRAY, MONEY, MONEY_ARRAY,
-    NUMERIC, NUMERIC_ARRAY, POINT, SMALLINT_ARRAY, TIME, TIMESTAMP,
-    TIMESTAMPTZ, TIMESTAMPTZ_ARRAY, TIMESTAMP_ARRAY, UUID_ARRAY, UUID_TYPE,
-    XID, pginterval_in, timedelta_in
-)
-
 import pytest
 
 import pytz
 
+from pg8000.converters import (
+    BIGINT,
+    BIGINT_ARRAY,
+    BOOLEAN,
+    CIDR_ARRAY,
+    DATE,
+    FLOAT_ARRAY,
+    INET,
+    INTEGER_ARRAY,
+    INTERVAL,
+    JSON,
+    JSONB,
+    JSONB_ARRAY,
+    JSON_ARRAY,
+    MONEY,
+    MONEY_ARRAY,
+    NUMERIC,
+    NUMERIC_ARRAY,
+    PGInterval,
+    POINT,
+    SMALLINT_ARRAY,
+    TIME,
+    TIMESTAMP,
+    TIMESTAMPTZ,
+    TIMESTAMPTZ_ARRAY,
+    TIMESTAMP_ARRAY,
+    UUID_ARRAY,
+    UUID_TYPE,
+    XID,
+    pg_interval_in,
+    pg_interval_out,
+    time_in,
+)
+
 
 def test_str_then_int(con):
     v1 = "hello world"
@@ -51,9 +77,9 @@ def test_int_roundtrip(con):
     int8 = 20
 
     MAP = {
-        int2: 'int2',
-        int4: 'int4',
-        int8: 'int8',
+        int2: "int2",
+        int4: "int4",
+        int8: "int8",
     }
 
     test_values = [
@@ -67,19 +93,21 @@ def test_int_roundtrip(con):
         (+2147483647, int4),
         (+2147483648, int8),
         (-9223372036854775807, int8),
-        (+9223372036854775807, int8)]
+        (+9223372036854775807, int8),
+    ]
 
     for value, typoid in test_values:
         retval = con.run("SELECT cast(:v as " + MAP[typoid] + ")", v=value)
         assert retval[0][0] == value
-        column_type_oid = con.columns[0]['type_oid']
+        column_type_oid = con.columns[0]["type_oid"]
         assert column_type_oid == typoid
 
 
 def test_bytearray_subclass_round_trip(con):
     class BClass(bytearray):
         pass
-    binary = b'\x00\x01\x02\x03\x02\x01\x00'
+
+    binary = b"\x00\x01\x02\x03\x02\x01\x00"
     retval = con.run("SELECT cast(:v as bytea)", v=BClass(binary))
     assert retval[0][0] == binary
 
@@ -92,36 +120,24 @@ def test_timestamp_roundtrip(is_java, con):
     # Test that time zone doesn't affect it
     # Jython 2.5.3 doesn't have a time.tzset() so skip
     if not is_java:
-        orig_tz = os.environ.get('TZ')
-        os.environ['TZ'] = "America/Edmonton"
+        orig_tz = os.environ.get("TZ")
+        os.environ["TZ"] = "America/Edmonton"
         time.tzset()
 
         retval = con.run("SELECT cast(:v as timestamp)", v=v)
         assert retval[0][0] == v
 
         if orig_tz is None:
-            del os.environ['TZ']
+            del os.environ["TZ"]
         else:
-            os.environ['TZ'] = orig_tz
+            os.environ["TZ"] = orig_tz
         time.tzset()
 
 
-def test_interval_repr():
-    v = pg8000.PGInterval(microseconds=123456789, days=2, months=24)
-    assert repr(v) == '<PGInterval 24 months 2 days 123456789 microseconds>'
-
-
-def test_interval_in_1_year():
-    assert pginterval_in('1 year') == pg8000.PGInterval(years=1)
-
-
-def test_timedelta_in_2_months():
-    assert timedelta_in('2 hours')
-
-
 def test_interval_roundtrip(con):
-    con.register_in_adapter(1186, pginterval_in)
-    v = pg8000.PGInterval(microseconds=123456789, days=2, months=24)
+    con.register_in_adapter(INTERVAL, pg_interval_in)
+    con.register_out_adapter(PGInterval, INTERVAL, pg_interval_out)
+    v = PGInterval(microseconds=123456789, days=2, months=24)
     retval = con.run("SELECT cast(:v as interval)", v=v)
     assert retval[0][0] == v
 
@@ -130,19 +146,18 @@ def test_enum_str_round_trip(con):
     try:
         con.run("create type lepton as enum ('electron', 'muon', 'tau')")
 
-        v = 'muon'
+        v = "muon"
         retval = con.run("SELECT cast(:v as lepton) as f1", v=v)
         assert retval[0][0] == v
         con.run("CREATE TEMPORARY TABLE testenum (f1 lepton)")
-        con.run(
-            "INSERT INTO testenum VALUES (cast(:v as lepton))", v='electron')
+        con.run("INSERT INTO testenum VALUES (cast(:v as lepton))", v="electron")
     finally:
         con.run("drop table testenum")
         con.run("drop type lepton")
 
 
 def test_enum_custom_round_trip(con):
-    class Lepton():
+    class Lepton:
         # Implements PEP 435 in the minimal fashion needed
         __members__ = OrderedDict()
 
@@ -160,11 +175,10 @@ def test_enum_custom_round_trip(con):
 
     try:
         con.run("create type lepton as enum ('1', '2', '3')")
-        lepton_oid = con.run(
-            "select oid from pg_type where typname = 'lepton'")[0][0]
+        lepton_oid = con.run("select oid from pg_type where typname = 'lepton'")[0][0]
         con.register_out_adapter(Lepton, lepton_oid, lepton_out)
 
-        v = Lepton('muon', '2')
+        v = Lepton("muon", "2")
         retval = con.run("SELECT :v", v=v)
         assert retval[0][0] == v.value
     finally:
@@ -173,9 +187,9 @@ def test_enum_custom_round_trip(con):
 
 def test_enum_py_round_trip(con):
     class Lepton(Enum):
-        electron = '1'
-        muon = '2'
-        tau = '3'
+        electron = "1"
+        muon = "2"
+        tau = "3"
 
     try:
         con.run("create type lepton as enum ('1', '2', '3')")
@@ -185,16 +199,14 @@ def test_enum_py_round_trip(con):
         assert retval[0][0] == v.value
 
         con.run("CREATE TEMPORARY TABLE testenum (f1 lepton)")
-        con.run(
-            "INSERT INTO testenum VALUES (cast(:v as lepton))",
-            v=Lepton.electron)
+        con.run("INSERT INTO testenum VALUES (cast(:v as lepton))", v=Lepton.electron)
     finally:
         con.run("drop table testenum")
         con.run("drop type lepton")
 
 
 def test_xml_roundtrip(con):
-    v = '<genome>gatccgagtac</genome>'
+    v = "<genome>gatccgagtac</genome>"
     retval = con.run("select xmlparse(content :v) as f1", v=v)
     assert retval[0][0] == v
 
@@ -209,13 +221,13 @@ def test_int2vector_in(con):
 
 def test_timestamp_tz_out(con):
     retval = con.run(
-        "SELECT '2001-02-03 04:05:06.17 America/Edmonton'"
-        "::timestamp with time zone")
+        "SELECT '2001-02-03 04:05:06.17 America/Edmonton'" "::timestamp with time zone"
+    )
     dt = retval[0][0]
     assert dt.tzinfo is not None, "no tzinfo returned"
     assert dt.astimezone(Timezone.utc) == Datetime(
-        2001, 2, 3, 11, 5, 6, 170000, Timezone.utc), \
-        "retrieved value match failed"
+        2001, 2, 3, 11, 5, 6, 170000, Timezone.utc
+    ), "retrieved value match failed"
 
 
 def test_timestamp_tz_roundtrip(is_java, con):
@@ -236,13 +248,15 @@ def test_timestamp_mismatch(is_java, con):
             con.run(
                 "CREATE TEMPORARY TABLE TestTz "
                 "(f1 timestamp with time zone, "
-                "f2 timestamp without time zone)")
+                "f2 timestamp without time zone)"
+            )
             con.run(
                 "INSERT INTO TestTz (f1, f2) VALUES (:v1, :v2)",
                 # insert timestamp into timestamptz field (v1)
                 v1=Datetime(2001, 2, 3, 4, 5, 6, 170000),
                 # insert timestamptz into timestamp field (v2)
-                v2=mst.localize(Datetime(2001, 2, 3, 4, 5, 6, 170000)))
+                v2=mst.localize(Datetime(2001, 2, 3, 4, 5, 6, 170000)),
+            )
             retval = con.run("SELECT f1, f2 FROM TestTz")
 
             # when inserting a timestamp into a timestamptz field,
@@ -281,7 +295,7 @@ def test_boolean_in(con):
 
 
 def test_numeric_out(con):
-    for num in ('5000', '50.34'):
+    for num in ("5000", "50.34"):
         retval = con.run("SELECT " + num + "::numeric")
         assert str(retval[0][0]) == num
 
@@ -326,13 +340,18 @@ def test_text_out(con):
     assert retval[0][0] == "hello"
 
 
-def test_interval_in(con):
-    con.register_in_adapter(1186, pg8000.converters.pginterval_in)
+def test_pg_interval_in(con):
+    con.register_in_adapter(1186, pg_interval_in)
     retval = con.run(
-        "SELECT '1 month 16 days 12 hours 32 minutes 64 seconds'::interval")
-    expected_value = pg8000.PGInterval(
-        microseconds=(12 * 60 * 60 * 1000 * 1000) +
-        (32 * 60 * 1000 * 1000) + (64 * 1000 * 1000), days=16, months=1)
+        "SELECT CAST('1 month 16 days 12 hours 32 minutes 64 seconds' as INTERVAL)"
+    )
+    expected_value = PGInterval(
+        microseconds=(12 * 60 * 60 * 1000 * 1000)
+        + (32 * 60 * 1000 * 1000)
+        + (64 * 1000 * 1000),
+        days=16,
+        months=1,
+    )
     assert retval[0][0] == expected_value
 
 
@@ -354,7 +373,8 @@ def test_timestamp_out(con):
 def test_int4_array_out(con):
     retval = con.run(
         "SELECT '{1,2,3,4}'::INT[] AS f1, '{{1,2,3},{4,5,6}}'::INT[][] AS f2, "
-        "'{{{1,2},{3,4}},{{NULL,6},{7,8}}}'::INT[][][] AS f3")
+        "'{{{1,2},{3,4}},{{NULL,6},{7,8}}}'::INT[][][] AS f3"
+    )
     f1, f2, f3 = retval[0]
     assert f1 == [1, 2, 3, 4]
     assert f2 == [[1, 2, 3], [4, 5, 6]]
@@ -365,7 +385,8 @@ def test_int2_array_out(con):
     res = con.run(
         "SELECT '{1,2,3,4}'::INT2[] AS f1, "
         "'{{1,2,3},{4,5,6}}'::INT2[][] AS f2, "
-        "'{{{1,2},{3,4}},{{NULL,6},{7,8}}}'::INT2[][][] AS f3")
+        "'{{{1,2},{3,4}},{{NULL,6},{7,8}}}'::INT2[][][] AS f3"
+    )
     f1, f2, f3 = res[0]
     assert f1 == [1, 2, 3, 4]
     assert f2 == [[1, 2, 3], [4, 5, 6]]
@@ -376,7 +397,8 @@ def test_int8_array_out(con):
     res = con.run(
         "SELECT '{1,2,3,4}'::INT8[] AS f1, "
         "'{{1,2,3},{4,5,6}}'::INT8[][] AS f2, "
-        "'{{{1,2},{3,4}},{{NULL,6},{7,8}}}'::INT8[][][] AS f3")
+        "'{{{1,2},{3,4}},{{NULL,6},{7,8}}}'::INT8[][][] AS f3"
+    )
     f1, f2, f3 = res[0]
     assert f1 == [1, 2, 3, 4]
     assert f2 == [[1, 2, 3], [4, 5, 6]]
@@ -388,19 +410,20 @@ def test_bool_array_out(con):
         "SELECT '{TRUE,FALSE,FALSE,TRUE}'::BOOL[] AS f1, "
         "'{{TRUE,FALSE,TRUE},{FALSE,TRUE,FALSE}}'::BOOL[][] AS f2, "
         "'{{{TRUE,FALSE},{FALSE,TRUE}},{{NULL,TRUE},{FALSE,FALSE}}}'"
-        "::BOOL[][][] AS f3")
+        "::BOOL[][][] AS f3"
+    )
     f1, f2, f3 = res[0]
     assert f1 == [True, False, False, True]
     assert f2 == [[True, False, True], [False, True, False]]
-    assert f3 == [
-        [[True, False], [False, True]], [[None, True], [False, False]]]
+    assert f3 == [[[True, False], [False, True]], [[None, True], [False, False]]]
 
 
 def test_float4_array_out(con):
     res = con.run(
         "SELECT '{1,2,3,4}'::FLOAT4[] AS f1, "
         "'{{1,2,3},{4,5,6}}'::FLOAT4[][] AS f2, "
-        "'{{{1,2},{3,4}},{{NULL,6},{7,8}}}'::FLOAT4[][][] AS f3")
+        "'{{{1,2},{3,4}},{{NULL,6},{7,8}}}'::FLOAT4[][][] AS f3"
+    )
     f1, f2, f3 = res[0]
     assert f1 == [1, 2, 3, 4]
     assert f2 == [[1, 2, 3], [4, 5, 6]]
@@ -411,125 +434,133 @@ def test_float8_array_out(con):
     res = con.run(
         "SELECT '{1,2,3,4}'::FLOAT8[] AS f1, "
         "'{{1,2,3},{4,5,6}}'::FLOAT8[][] AS f2, "
-        "'{{{1,2},{3,4}},{{NULL,6},{7,8}}}'::FLOAT8[][][] AS f3")
+        "'{{{1,2},{3,4}},{{NULL,6},{7,8}}}'::FLOAT8[][][] AS f3"
+    )
     f1, f2, f3 = res[0]
     assert f1 == [1, 2, 3, 4]
     assert f2 == [[1, 2, 3], [4, 5, 6]]
     assert f3 == [[[1, 2], [3, 4]], [[None, 6], [7, 8]]]
 
 
+CURRENCIES = {
+    "en_GB.UTF-8": "£",
+    "C.UTF-8": "$",
+}
+LANG = os.environ["LANG"]
+CURRENCY = CURRENCIES[LANG]
+
+
 @pytest.mark.parametrize(
     "test_input,oid",
     [
-        [[True, False, None], None],  # bool[]
-        [[IPv4Address('192.168.0.1')], None],  # inet[]
-        [[Date(2021, 3, 1)], None],  # date[]
-        [[Datetime(2001, 2, 3, 4, 5, 6)], None],  # timestamp[]
         [[Datetime(2001, 2, 3, 4, 5, 6)], TIMESTAMP_ARRAY],  # timestamp[]
-        [  # timestamptz
-            [Datetime(2001, 2, 3, 4, 5, 6, 0, Timezone.utc)], None
-        ],
         [  # timestamptz[]
-            [Datetime(2001, 2, 3, 4, 5, 6, 0, Timezone.utc)], TIMESTAMPTZ_ARRAY
+            [Datetime(2001, 2, 3, 4, 5, 6, 0, Timezone.utc)],
+            TIMESTAMPTZ_ARRAY,
         ],
         [
-            {'name': 'Apollo 11 Cave', 'zebra': True, 'age': 26.003},
+            {"name": "Apollo 11 Cave", "zebra": True, "age": 26.003},
             # json
-            JSON
+            JSON,
         ],
-        [  # jsonb
-            {'name': 'Apollo 11 Cave', 'zebra': True, 'age': 26.003},
-            JSONB
-        ],
-        [  # jsonb
-            {'name': 'Apollo 11 Cave', 'zebra': True, 'age': 26.003},
-            None
-        ],
-        [[b'\x00\x01\x02\x03\x02\x01\x00'], None],  # bytea[]
-        [[IPv4Network('192.168.0.0/28')], CIDR_ARRAY],  # cidr[]
+        [{"name": "Apollo 11 Cave", "zebra": True, "age": 26.003}, JSONB],  # jsonb
+        [[IPv4Network("192.168.0.0/28")], CIDR_ARRAY],  # cidr[]
         [[1, 2, 3], SMALLINT_ARRAY],  # int2[]
         [[[1, 2], [3, 4]], SMALLINT_ARRAY],  # int2[] multidimensional
         [[1, None, 3], INTEGER_ARRAY],  # int4[] with None
         [[7000000000, 2, 3], BIGINT_ARRAY],  # int8[]
         [[1.1, 2.2, 3.3], FLOAT_ARRAY],  # float8[]
-        [[Decimal("1.1"), None, Decimal("3.3")], None],  # numeric[]
         [[Decimal("1.1"), None, Decimal("3.3")], NUMERIC_ARRAY],  # numeric[]
-        [["1.10", None, "3.30"], MONEY_ARRAY],  # money[]
-        [[UUID('911460f2-1f43-fea2-3e2c-e01fd5b5069d')], None],  # uuid[]
-        [[UUID('911460f2-1f43-fea2-3e2c-e01fd5b5069d')], UUID_ARRAY],  # uuid[]
-        [
-            [
-                "Hello!", "World!", "abcdefghijklmnopqrstuvwxyz", "",
-                "A bunch of random characters:",
-                " ~!@#$%^&*()_+`1234567890-=[]\\{}|{;':\",./<>?\t", None
-            ],
-            None
-        ],
+        [[f"{CURRENCY}1.10", None, f"{CURRENCY}3.30"], MONEY_ARRAY],  # money[]
+        [[UUID("911460f2-1f43-fea2-3e2c-e01fd5b5069d")], UUID_ARRAY],  # uuid[]
         [  # json[]
-            [{'name': 'Apollo 11 Cave', 'zebra': True, 'age': 26.003}],
-            JSON_ARRAY
+            [{"name": "Apollo 11 Cave", "zebra": True, "age": 26.003}],
+            JSON_ARRAY,
         ],
         [  # jsonb[]
-            [{'name': 'Apollo 11 Cave', 'zebra': True, 'age': 26.003}],
-            JSONB_ARRAY
+            [{"name": "Apollo 11 Cave", "zebra": True, "age": 26.003}],
+            JSONB_ARRAY,
+        ],
+        [Time(4, 5, 6), TIME],  # time
+        [Date(2001, 2, 3), DATE],  # date
+        [Datetime(2001, 2, 3, 4, 5, 6), TIMESTAMP],  # timestamp
+        [Datetime(2001, 2, 3, 4, 5, 6, 0, Timezone.utc), TIMESTAMPTZ],  # timestamptz
+        [True, BOOLEAN],  # bool
+        [None, BOOLEAN],  # null
+        [Decimal("1.1"), NUMERIC],  # numeric
+        [f"{CURRENCY}1.10", MONEY],  # money
+        [f"-{CURRENCY}1.10", MONEY],  # money
+        [50000000000000, BIGINT],  # int8
+        [UUID("911460f2-1f43-fea2-3e2c-e01fd5b5069d"), UUID_TYPE],  # uuid
+        [IPv4Network("192.168.0.0/28"), INET],  # inet
+        [IPv4Address("192.168.0.1"), INET],  # inet
+        [86722, XID],  # xid
+        ["infinity", TIMESTAMP],  # timestamp
+        ["(2.3,1)", POINT],  # point
+        [{"name": "Apollo 11 Cave", "zebra": True, "age": 26.003}, JSON],  # json
+        [{"name": "Apollo 11 Cave", "zebra": True, "age": 26.003}, JSONB],  # jsonb
+    ],
+)
+def test_roundtrip_oid(con, test_input, oid):
+
+    retval = con.run("SELECT :v", v=test_input, types={"v": oid})
+    assert retval[0][0] == test_input
+
+    assert oid == con.columns[0]["type_oid"]
+
+
+@pytest.mark.parametrize(
+    "test_input,required_version",
+    [
+        [[True, False, None], None],  # bool[]
+        [[IPv4Address("192.168.0.1")], None],  # inet[]
+        [[Date(2021, 3, 1)], None],  # date[]
+        [[Datetime(2001, 2, 3, 4, 5, 6)], None],  # timestamp[]
+        [[Datetime(2001, 2, 3, 4, 5, 6, 0, Timezone.utc)], None],  # timestamptz[]
+        [[Time(4, 5, 6)], None],  # time[]
+        [[Timedelta(seconds=30)], None],  # interval[]
+        [[{"name": "Apollo 11 Cave", "zebra": True, "age": 26.003}], None],  # jsonb[]
+        [[b"\x00\x01\x02\x03\x02\x01\x00"], None],  # bytea[]
+        [[Decimal("1.1"), None, Decimal("3.3")], None],  # numeric[]
+        [[UUID("911460f2-1f43-fea2-3e2c-e01fd5b5069d")], None],  # uuid[]
+        [  # varchar[]
+            [
+                "Hello!",
+                "World!",
+                "abcdefghijklmnopqrstuvwxyz",
+                "",
+                "A bunch of random characters:",
+                " ~!@#$%^&*()_+`1234567890-=[]\\{}|{;':\",./<>?\t",
+                None,
+            ],
+            None,
         ],
         [Timedelta(seconds=30), None],  # interval
         [Time(4, 5, 6), None],  # time
-        [Time(4, 5, 6), TIME],  # time
         [Date(2001, 2, 3), None],  # date
-        [Date(2001, 2, 3), DATE],  # date
         [Datetime(2001, 2, 3, 4, 5, 6), None],  # timestamp
-        [Datetime(2001, 2, 3, 4, 5, 6), TIMESTAMP],  # timestamp
         [Datetime(2001, 2, 3, 4, 5, 6, 0, Timezone.utc), None],  # timestamptz
-        [  # timestamptz
-            Datetime(2001, 2, 3, 4, 5, 6, 0, Timezone.utc), TIMESTAMPTZ
-        ],
-        [True, None],  # bool
-        [True, BOOLEAN],  # bool
-        [None, BOOLEAN],  # null (needs a type on PostgreSQL 9.6)
+        [True, 10],  # bool
         [Decimal("1.1"), None],  # numeric
-        [Decimal("1.1"), NUMERIC],  # numeric
-        ["1.10", MONEY],  # money
         [1.756e-12, None],  # float8
-        [float('inf'), None],  # float8
-        ["hello world", None],  # unknown
-        ["hello \u0173 world", None],  # unknown
+        [float("inf"), None],  # float8
+        ["hello world", 10],  # unknown
+        ["hello \u0173 world", 10],  # varchar
         [50000000000000, None],  # int8
-        [50000000000000, BIGINT],  # int8
         [b"\x00\x01\x02\x03\x02\x01\x00", None],  # bytea
-        [bytearray(b'\x00\x01\x02\x03\x02\x01\x00'), None],  # bytea
-        [UUID('911460f2-1f43-fea2-3e2c-e01fd5b5069d'), None],  # uuid
-        [UUID('911460f2-1f43-fea2-3e2c-e01fd5b5069d'), UUID_TYPE],  # uuid
-        [IPv4Network('192.168.0.0/28'), None],  # inet
-        [IPv4Network('192.168.0.0/28'), INET],  # inet
-        [IPv4Address('192.168.0.1'), None],  # inet
-        [IPv4Address('192.168.0.1'), INET],  # inet
-        [86722, XID],  # xid
-        ['infinity', TIMESTAMP],  # timestamp
-        ['(2.3,1)', POINT],  # point
-        [  # json
-            {'name': 'Apollo 11 Cave', 'zebra': True, 'age': 26.003},
-            JSON
-        ],
-        [  # jsonb
-            {'name': 'Apollo 11 Cave', 'zebra': True, 'age': 26.003},
-            JSONB
-        ],
-    ]
+        [bytearray(b"\x00\x01\x02\x03\x02\x01\x00"), None],  # bytea
+        [UUID("911460f2-1f43-fea2-3e2c-e01fd5b5069d"), None],  # uuid
+        [IPv4Network("192.168.0.0/28"), None],  # inet
+        [IPv4Address("192.168.0.1"), None],  # inet
+    ],
 )
-def test_roundtrip(con, pg_version, test_input, oid):
-    if oid is None and pg_version < 10:
+def test_roundtrip_bare(con, pg_version, test_input, required_version):
+    if required_version is not None and pg_version < required_version:
         return
 
-    types = None if oid is None else {'v': oid}
-
-    retval = con.run("SELECT :v", v=test_input, types=types)
+    retval = con.run("SELECT :v", v=test_input)
     assert retval[0][0] == test_input
 
-    if types is not None:
-        column_type_oid = con.columns[0]['type_oid']
-        assert column_type_oid == types['v']
-
 
 @pytest.mark.parametrize(
     "test_input,expected",
@@ -540,11 +571,8 @@ def test_roundtrip(con, pg_version, test_input, oid):
         ("SELECT CAST('{a,b,c}' AS CSTRING[])", ["a", "b", "c"]),
         ("SELECT CAST('{a,b,c}' AS NAME[])", ["a", "b", "c"]),
         ("SELECT CAST('{}' AS text[])", []),
-        (
-            "SELECT CAST('{NULL,\"NULL\",NULL,\"\"}' AS text[])",
-            [None, 'NULL', None, ""]
-        )
-    ]
+        ('SELECT CAST(\'{NULL,"NULL",NULL,""}\' AS text[])', [None, "NULL", None, ""]),
+    ],
 )
 def test_array_in(con, test_input, expected):
     result = con.run(test_input)
@@ -556,12 +584,6 @@ def test_numeric_array_out(con):
     assert res[0][0] == [Decimal("1.1"), Decimal("2.2"), Decimal("3.3")]
 
 
-def test_array_string_escape():
-    v = "\""
-    res = pg8000.converters.array_string_escape(v)
-    assert res == '"\\""'
-
-
 def test_empty_array(con):
     v = []
     retval = con.run("SELECT cast(:v as varchar[])", v=v)
@@ -575,8 +597,8 @@ def test_macaddr(con):
 
 def test_tsvector_roundtrip(con):
     retval = con.run(
-        "SELECT cast(:v as tsvector)",
-        v='a fat cat sat on a mat and ate a fat rat')
+        "SELECT cast(:v as tsvector)", v="a fat cat sat on a mat and ate a fat rat"
+    )
     assert retval[0][0] == "'a' 'and' 'ate' 'cat' 'fat' 'mat' 'on' 'rat' 'sat'"
 
 
@@ -587,46 +609,42 @@ def test_hstore_roundtrip(con):
 
 
 def test_json_access_object(con):
-    val = {'name': 'Apollo 11 Cave', 'zebra': True, 'age': 26.003}
-    retval = con.run(
-        "SELECT cast(:val as json) -> :name", val=dumps(val), name='name')
-    assert retval[0][0] == 'Apollo 11 Cave'
+    val = {"name": "Apollo 11 Cave", "zebra": True, "age": 26.003}
+    retval = con.run("SELECT cast(:val as json) -> :name", val=dumps(val), name="name")
+    assert retval[0][0] == "Apollo 11 Cave"
 
 
 def test_jsonb_access_object(con):
-    val = {'name': 'Apollo 11 Cave', 'zebra': True, 'age': 26.003}
-    retval = con.run(
-        "SELECT cast(:val as jsonb) -> :name", val=dumps(val), name='name')
-    assert retval[0][0] == 'Apollo 11 Cave'
+    val = {"name": "Apollo 11 Cave", "zebra": True, "age": 26.003}
+    retval = con.run("SELECT cast(:val as jsonb) -> :name", val=dumps(val), name="name")
+    assert retval[0][0] == "Apollo 11 Cave"
 
 
 def test_json_access_array(con):
     val = [-1, -2, -3, -4, -5]
     retval = con.run(
-        "SELECT cast(:v1 as json) -> cast(:v2 as int)",
-        v1=dumps(val), v2=2)
+        "SELECT cast(:v1 as json) -> cast(:v2 as int)", v1=dumps(val), v2=2
+    )
     assert retval[0][0] == -3
 
 
 def test_jsonb_access_array(con):
     val = [-1, -2, -3, -4, -5]
     retval = con.run(
-        "SELECT cast(:v1 as jsonb) -> cast(:v2 as int)", v1=dumps(val), v2=2)
+        "SELECT cast(:v1 as jsonb) -> cast(:v2 as int)", v1=dumps(val), v2=2
+    )
     assert retval[0][0] == -3
 
 
 def test_jsonb_access_path(con):
-    j = {
-        "a": [1, 2, 3],
-        "b": [4, 5, 6]}
+    j = {"a": [1, 2, 3], "b": [4, 5, 6]}
 
-    path = ['a', '2']
+    path = ["a", "2"]
 
-    retval = con.run(
-        "SELECT cast(:v1 as jsonb) #>> :v2", v1=dumps(j), v2=path)
+    retval = con.run("SELECT cast(:v1 as jsonb) #>> :v2", v1=dumps(j), v2=path)
     assert retval[0][0] == str(j[path[0]][int(path[1])])
 
 
 def test_time_in():
-    actual = pg8000.converters.time_in("12:57:18.000396")
+    actual = time_in("12:57:18.000396")
     assert actual == Time(12, 57, 18, 396)
